@@ -128,7 +128,7 @@ class CGDB:
         """
         return self._aggregations_manager.aggregations()
 
-    def create_data_set(self, site, element_code, aggregation_code, time_step_code, data_set_type):
+    def create_data_set(self, site, element_code, aggregation_code, time_step_code, data_set_type, elementMarkOverride= None, level_code=None):
         """Create data set
 
              :type site: Site
@@ -144,7 +144,7 @@ class CGDB:
              :param time_step_code: code of time_step
          """
 
-        self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, data_set_type)
+        self._data_sets_manager.create_data_set(site, element_code, aggregation_code, time_step_code, data_set_type, elementMarkOverride,)
 
     def create_station(self, name: str, code: str, gpsLatitude: float, gpsLongitude: float, altitude: int, stationNetworkCode, remark=""):
         """Create station
