@@ -274,4 +274,5 @@ class DataSetsManager(ManagerMix):
                    "dataSetType": data_set_type,
                    "description": description}
 
-        self.post(url, json.dumps(content))
\ No newline at end of file
+        test = self.post(url, json.dumps(content))
+        print(test)
\ No newline at end of file
