@@ -1,4 +1,4 @@
-from cgdb.recources.elementContext import ElementContext
+from cgdb.resources.elementContext import ElementContext
 from cgdb.utils.ManagerMix import ManagerMix
 
 
